---
# Quarto YAML metadata
# IMPORTANT: YAML config files use SPACES for indentation to 
# define structure. Remember: STRAIGHTEN all smart quotes and don't
# capitalise metadata keys, they MUST BE lowercase! 
# Tip: use "Show Invisibles" in Scrivener to see whitespaces.
# 
# Metadata is used to define the options that Quarto/Pandoc
# use when generating the final document. You will need to change
# the location of your bibliography files and change any fonts
# to those present on your system.
#
title: "Image Test"
affiliations:
  - id: cebsit
    name: Center for Excellence in Brain Science and Intelligence Technology, Institute of Neuroscience, Chinese Academy of Sciences, 320 Yueyang rd, Shanghai 200031, China
  - id: inserm
    name: Sorbonne Université, Inserm, CNRS, ICM, Paris, France
  - id: york
    name: Glendon College and Centre for Vision Research, York University, Toronto, Canada
author: 
  - name: Jane Doe
    affiliation: 
      - ref: inserm
    email: jdoe@gmail.com
    corresponding: true
  - name: John Doe
    affiliation: 
      - ref: cebsit
    email: jdoe@gmail.com
    corresponding: true
keywords: [isoluminance, color perception, pupillometry, no-report paradigm, frequency-tagging]
lang: en
date: 2023-09-29       # Scrivener placeholder
verbose: true                  # pandoc verbosity
toc: false                     # table of contents
number-sections: false         # numbered headings
crossref:                      # cross-referencing options
  labels: arabic                # (default is arabic)
  subref-labels: alpha A        # (default is alpha a)
  chapters: false                # Numbers depend on the chapter, e.g. 2.1
cap-location: bottom           # where put figure & table captions
link-citations: true           # in-document links to refs
link-bibliography: true        # in-bib links to refs
bibliography: ${USERHOME}/.local/share/pandoc/Core.json
csl: ${USERHOME}/.local/share/pandoc/csl/apa.csl
appendix-style: default       # see https://quarto.org/docs/authoring/appendices.html#appendix-style
title-block-style: default
dpi: 300
format:
  docx:
    prefer-html: true          # stops non-HTML format errors 
    reference-doc: ${USERHOME}/.local/share/pandoc/templates/custom-calibri.docx # change to your own docx template
  html:
    toc: true
    toc-location: right
    theme: journal
    title-block-banner: "#BB3333"
    embed-resources: false
    html-math-method: mathjax
    section-divs: true
    linestretch: 1.5
    fig-format: svg
    mainfont: Alegreya         # !!! Change to a font on your system
    monofont: Rec Mono Duotone # !!! Change to a font on your system
    # Inject some style tweaks into the header
    header-includes: |
      <Style>
        div.quarto-title-meta-author, div.quarto-title-meta, div.keywords { display: none !important;}
        div.author p {font-size: 1.2em; font-weight: bold; font-style: italic; text-align: center !important;}
        p {text-align: justify;}
        tr.odd {background-color: #F1F1F1;}
        caption, figcaption, .column-margin p {font-family: Alegreya Sans, sans-serif !important; text-align: left !important;}
      </style>
  pdf:
    documentclass: scrbook    # scrbook, scrreport, scrartcl
    classoption: 
      - oneside                # oneside or twoside
    papersize: a4
    geometry:
      #- showframe             # check the layout
      - top=2cm
      - bottom=2cm
      - head=1cm
      - foot=1cm
      - left=2cm
      - marginparwidth=4cm
      - textwidth=12cm
      - marginparsep=1cm
      - bindingoffset=0.5cm
    fontsize: 12pt
    linestretch: 1.5
    latex-clean: true
    keep-tex: true
    mainfont: Alegreya         # !!! Change to a font on your system
    mainfontoptions: 
      - Numbers=Proportional
      - Numbers=OldStyle
    sansfont: Alegreya Sans    # !!! Change to a font on your system
    monofont: Rec Mono Duotone # !!! Change to a font on your system
    monofontoptions: 
      - Scale=MatchLowercase
    mathfont: Libertinus Math  # !!! Change to a font on your system
    linkcolor: Mahogany
    citecolor: Bittersweet
    urlcolor: BrickRed
    #header-includes: |
      #\KOMAoptions{DIV=last}  # force koma layout rather than geometry
  epub:
    html-math-method: katex
    identifier: 45DRE66-YTX
    epub-cover-image: ${USERHOME}/.local/share/pandoc/templates/cover.jpg
    fig-format: png
---



::: {custom-style="Author" .author}
Jane Doe^2‡^,   John Doe^1‡^
:::


‡ These authors contributed equally to this work.

**\* Corresponding authors: Jane and John**

Affiliations:

1. Sorbonne Université, Inserm, CNRS, ICM, Paris, France
2. Center for Excellence in Brain Science and Intelligence Technology, Institute of Neuroscience, Chinese Academy of Sciences, 320 Yueyang rd, Shanghai, China


# Abstract




These are the voyages of the Starship Enterprise. Its continuing mission, to explore strange new worlds, to seek out new life and new civilizations, to boldly go where no one has gone before. We need to neutralize the homing signal. Each unit has total environmental control, gravity, temperature, atmosphere, light, in a protective field. Sensors show energy readings in your area. We had a forced chamber explosion in the resonator coil. Field strength has increased by 3,000 percent.



## Key words




isoluminance, color perception, pupillometry, no-report paradigm, frequency-tagging


# Introduction




Unidentified vessel travelling at sub warp speed, bearing 235.7. Fluctuations in energy readings from it, Captain. All transporters off. A strange set-up, but I'd say the graviton generator is depolarized. The dark colourings of the scrapes are the leavings of natural rubber, a type of non-conductive sole used by researchers experimenting with electricity. The molecules must have been partly de-phased by the anyon beam.

![{#fig-png} (**a**) Interesting.  (**b**) Boring.][PNG]


I have reset the sensors to scan for frequencies outside the usual range. By emitting harmonic vibrations to shatter the lattices. We will monitor and adjust the frequency of the resonators. He has this ability of instantly interpreting and extrapolating any verbal communication he hears. It may be due to the envelope over the structure, causing hydrogen-carbon helix patterns throughout. I'm comparing the molecular integrity of that bubble against our phasers.

![{#fig-pdf} (**a**) Interesting.  (**b**) Boring.][PDF]


Now what are the possibilities of warp drive? Cmdr Riker's nervous system has been invaded by an unknown microorganism. The organisms fuse to the nerve, intertwining at the molecular level. That's why the transporter's biofilters couldn't extract it. The vertex waves show a K-complex corresponding to an REM state. The engineering section's critical. Destruction is imminent. Their robes contain ultritium, highly explosive, virtually undetectable by your transporter.

Deflector power at maximum. Energy discharge in six seconds. Warp reactor core primary coolant failure. Fluctuate phaser resonance frequencies. Resistance is futile. Recommend we adjust shield harmonics to the upper EM band when proceeding. These appear to be some kind of power-wave-guide conduits which allow them to work collectively as they perform ship functions. Increase deflector modulation to upper frequency band.

Exceeding reaction chamber thermal limit. We have begun power-supply calibration. Force fields have been established on all turbo lifts and crawlways. Computer, run a level-two diagnostic on warp-drive systems. Antimatter containment positive. Warp drive within normal parameters. I read an ion trail characteristic of a freighter escape pod. The bomb had a molecular-decay detonator. Detecting some unusual fluctuations in subspace frequencies.

Resistance is futile.

[PNG]: PNG.png {width=595 height=233}

[PDF]: PDF.pdf {width=596 height=233}